import { createFilter } from 'rollup-pluginutils';
import istanbul from 'istanbul';

export default function( options = {} ) {
	const filter = createFilter(options.include, options.exclude);

	return {
		transform ( code, id ) {
		if (!filter(id)) return;

		const sourceMap  = options.sourceMapID !== false;
		const opts = Object.assign({}, options.instrumenterConfig);

		if (sourceMap ) {
			opts.codeGenerationOptions = Object.assign({},
				opts.codeGenerationOptions || {format: {compact: !opts.noCompact}},
				{sourceMap: id, sourceMapWithCode: true, file: code}
			);
		}

		opts.esModules = true;
		const instrumenter = new (options.instrumenter || istanbul).Instrumenter(opts);

		code = instrumenter.instrumentSync(code, id);

		let map;

		if (sourceMap ) {
			map = instrumenter.lastSourceMap().toJSON();
		} else {
			map =  {mappings: ''};
		}

		return { code, map };
	}
};
}